summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMark Eichin <eichin@thok.org>2014-07-04 12:59:20 -0400
committerMark Eichin <eichin@thok.org>2014-07-04 12:59:20 -0400
commite89ee1b94c773b1b9449bffb06985a591a82ae1e (patch)
treea7d1adc2c9f1b6e07cd5dacd8e44ceb27f60c08b
parentbc1feaa9e9b8f672c0a860cb745a666088118974 (diff)
2.2.2-4
-rw-r--r--aim.c4
-rw-r--r--commands.c4
-rw-r--r--debian/changelog10
-rw-r--r--debian/control1
-rw-r--r--debian/shlibs.local1
-rw-r--r--doc/code.txt2
-rw-r--r--libfaim/chatnav.c2
-rw-r--r--libfaim/im.c2
-rw-r--r--variable.c2
9 files changed, 19 insertions, 9 deletions
diff --git a/commands.c b/commands.c
index 39fb2bf..11c6a51 100644
--- a/commands.c
+++ b/commands.c
@@ -297,8 +297,8 @@ owl_cmd commands_to_init[]
"suppress a given zephyr triplet",
"zpunt <class> <instance> [recipient]\n"
"zpunt <instance>",
- "The zpunt command will supress message to the specified\n"
- "zephyr triplet. In the second usage messages as supressed\n"
+ "The zpunt command will suppress message to the specified\n"
+ "zephyr triplet. In the second usage messages as suppressed\n"
"for class MESSAGE and the named instance.\n\n"
"SEE ALSO: zunpunt, show zpunts\n"),
diff --git a/debian/changelog b/debian/changelog
index 5115f71..a26e545 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,13 @@
+owl (2.2.2-4) unstable; urgency=medium
+
+ * aim.c commands.c doc/code.txt libfaim/chatnav.c libfaim/im.c variable.c:
+ lintian spelling-error-in-binary (most of which were actually user-visible.)
+ * debian/control: lintian no-homepage-field.
+ * debian/shlibs.local: #148175 was fixed 12 years ago (see 1.0.1-3
+ below) so drop the no-longer-needed file.
+
+ -- Mark W. Eichin <eichin@thok.org> Fri, 04 Jul 2014 12:58:53 -0400
+
owl (2.2.2-3) unstable; urgency=medium
* debian/rules, debian/control, debian/compat: minimal-dh 9.
diff --git a/debian/control b/debian/control
index 88c4761..fd6a3ab 100644
--- a/debian/control
+++ b/debian/control
@@ -1,6 +1,7 @@
Source: owl
Section: net
Priority: optional
+Homepage: http://www.ktools.org/owl/
Maintainer: Mark W. Eichin <eichin@thok.org>
Build-Depends: debhelper (>> 9), libzephyr-dev (>= 3.0~beta), libncurses5-dev, libkrb5-dev, libperl-dev, libssl-dev, libglib2.0-dev, ncurses-term
Standards-Version: 3.9.5
diff --git a/debian/shlibs.local b/debian/shlibs.local
deleted file mode 100644
index c852f44..0000000
--- a/debian/shlibs.local
+++ /dev/null
@@ -1 +0,0 @@
-libzephyr 3 libzephyr3
diff --git a/doc/code.txt b/doc/code.txt
index 682315c..13e2368 100644
--- a/doc/code.txt
+++ b/doc/code.txt
@@ -163,7 +163,7 @@ CURSES WINDOWS
The four curses windows on the screen are
recwin - receiving window
- sepwin - seperator window
+ sepwin - separator window
msgwin - message window
typwin - typing window
diff --git a/libfaim/chatnav.c b/libfaim/chatnav.c
index 1b97b98..bc3eb1f 100644
--- a/libfaim/chatnav.c
+++ b/libfaim/chatnav.c
@@ -379,7 +379,7 @@ static int parseinfo(aim_session_t *sess, aim_module_t *mod, aim_frame_t *rx, ai
}
if (snac2->family != 0x000d) {
- faimdprintf(sess, 0, "faim: chatnav_parse_info: recieved response that maps to corrupt request! (fam=%04x)\n", snac2->family);
+ faimdprintf(sess, 0, "faim: chatnav_parse_info: received response that maps to corrupt request! (fam=%04x)\n", snac2->family);
return 0;
}
diff --git a/libfaim/im.c b/libfaim/im.c
index ebe64fc..e5934c9 100644
--- a/libfaim/im.c
+++ b/libfaim/im.c
@@ -1024,7 +1024,7 @@ static int outgoingim(aim_session_t *sess, aim_module_t *mod, aim_frame_t *rx, a
channel = aimbs_get16(bs);
if (channel != 0x01) {
- faimdprintf(sess, 0, "icbm: ICBM recieved on unsupported channel. Ignoring. (chan = %04x)\n", channel);
+ faimdprintf(sess, 0, "icbm: ICBM received on unsupported channel. Ignoring. (chan = %04x)\n", channel);
return 0;
}
diff --git a/variable.c b/variable.c
index d17a9b7..5fbe8e7 100644
--- a/variable.c
+++ b/variable.c
@@ -107,7 +107,7 @@ static owl_variable variables_to_init[] = {
"send pings", "" ),
OWLVAR_BOOL( "sepbar_disable" /* %OwlVarStub */, 0,
- "disable printing information in the seperator bar", "" ),
+ "disable printing information in the separator bar", "" ),
OWLVAR_BOOL( "smartstrip" /* %OwlVarStub */, 1,
"strip kerberos instance for reply", ""),
diff --git a/aim.c b/aim.c
index 28ebce5..e97884c 100644
--- a/aim.c
+++ b/aim.c
@@ -1010,7 +1010,7 @@ static int getaimdata(aim_session_t *sess, unsigned char **bufret, int *buflenre
int i;
owl_free(filename); /* not needed */
- owl_function_error("getaimdata memrequest: recieved invalid request for 0x%08lx bytes at 0x%08lx (file %s)\n", len, offset, modname);
+ owl_function_error("getaimdata memrequest: received invalid request for 0x%08lx bytes at 0x%08lx (file %s)\n", len, offset, modname);
i = 8;
if (modname) {
i+=strlen(modname);
@@ -1221,7 +1221,7 @@ static int faimtest_handlecmd(aim_session_t *sess, aim_conn_t *conn, aim_userinf
* Apparently if you set the charset to something WinAIM
* doesn't recognize, it will completly ignore the message.
* That is, it will not display anything in the conversation
* window for the user that recieved it.
*
* HOWEVER, if they do not have a conversation window open
* for you, a new one will be created, but it will not have
@@ -1221,7 +1221,7 @@ static int faimtest_handlecmd(aim_session_t *sess, aim_conn_t *conn, aim_userinf
* doesn't recognize, it will completly ignore the message.
* That is, it will not display anything in the conversation
- * window for the user that recieved it.
+ * window for the user that received it.
*
* HOWEVER, if they do not have a conversation window open